@@ -53,17 +53,14 @@ fn build_man_page() -> std::io::Result<()> {
     Ok(())
 }
 
-fn detect_trash() -> std::io::Result<()> {
+fn detect_trash() {
     println!("cargo::rustc-check-cfg=cfg(trash, values(none()))");
-
     if cfg!(any(
         target_os = "windows",
         all(unix, not(target_os = "ios"), not(target_os = "android"))
     )) {
         println!("cargo::rustc-cfg=trash");
     }
-
-    Ok(())
 }
 
 fn main() -> std::io::Result<()> {
@@ -71,6 +68,6 @@ fn main() -> std::io::Result<()> {
     if BUILD_MAN_PAGE {
         build_man_page()?;
     }
-    detect_trash()?;
+    detect_trash();
     Ok(())
 }
