@@ -5,9 +5,7 @@ use {
         errors::PatternError,
     },
     bet::BeTree,
-    std::{
-        path::Path,
-    },
+    std::path::Path,
 };
 
 /// a pattern for filtering and sorting files.
@@ -28,60 +26,44 @@ pub enum Pattern {
 }
 
 impl Pattern {
-
     pub fn new(
         raw_expr: &BeTree<PatternOperator, PatternParts>,
         search_modes: &SearchModeMap,
         content_search_max_file_size: usize,
     ) -> Result<Self, PatternError> {
-        let expr: BeTree<PatternOperator, Pattern> = raw_expr
-            .try_map_atoms::<_, PatternError, _>(|pattern_parts| {
+        let expr: BeTree<PatternOperator, Pattern> =
+            raw_expr.try_map_atoms::<_, PatternError, _>(|pattern_parts| {
                 let core = pattern_parts.core();
-                Ok(
-                    if core.is_empty() {
-                        Pattern::None
-                    } else {
-                        let parts_mode = pattern_parts.mode();
-                        let mode = search_modes.search_mode(parts_mode)?;
-                        let flags = pattern_parts.flags();
-                        match mode {
-                            SearchMode::NameExact => Self::NameExact(
-                                ExactPattern::from(core)
-                            ),
-                            SearchMode::NameFuzzy => Self::NameFuzzy(
-                                FuzzyPattern::from(core)
-                            ),
-                            SearchMode::NameRegex => Self::NameRegex(
-                                RegexPattern::from(core, flags.unwrap_or(""))?
-                            ),
-                            SearchMode::NameTokens => Self::NameTokens(
-                                TokPattern::new(core)
-                            ),
-                            SearchMode::PathExact => Self::PathExact(
-                                ExactPattern::from(core)
-                            ),
-                            SearchMode::PathFuzzy => Self::PathFuzzy(
-                                FuzzyPattern::from(core)
-                            ),
-                            SearchMode::PathRegex => Self::PathRegex(
-                                RegexPattern::from(core, flags.unwrap_or(""))?
-                            ),
-                            SearchMode::PathTokens => Self::PathTokens(
-                                TokPattern::new(core)
-                            ),
-                            SearchMode::ContentExact => Self::ContentExact(
-                                ContentExactPattern::new(core, content_search_max_file_size)
-                            ),
-                            SearchMode::ContentRegex => Self::ContentRegex(
-                                ContentRegexPattern::new(
-                                    core,
-                                    flags.unwrap_or(""),
-                                    content_search_max_file_size,
-                                )?
-                            ),
+                Ok(if core.is_empty() {
+                    Pattern::None
+                } else {
+                    let parts_mode = pattern_parts.mode();
+                    let mode = search_modes.search_mode(parts_mode)?;
+                    let flags = pattern_parts.flags();
+                    match mode {
+                        SearchMode::NameExact => Self::NameExact(ExactPattern::from(core)),
+                        SearchMode::NameFuzzy => Self::NameFuzzy(FuzzyPattern::from(core)),
+                        SearchMode::NameRegex => {
+                            Self::NameRegex(RegexPattern::from(core, flags.unwrap_or(""))?)
                         }
+                        SearchMode::NameTokens => Self::NameTokens(TokPattern::new(core)),
+                        SearchMode::PathExact => Self::PathExact(ExactPattern::from(core)),
+                        SearchMode::PathFuzzy => Self::PathFuzzy(FuzzyPattern::from(core)),
+                        SearchMode::PathRegex => {
+                            Self::PathRegex(RegexPattern::from(core, flags.unwrap_or(""))?)
+                        }
+                        SearchMode::PathTokens => Self::PathTokens(TokPattern::new(core)),
+                        SearchMode::ContentExact => Self::ContentExact(ContentExactPattern::new(
+                            core,
+                            content_search_max_file_size,
+                        )),
+                        SearchMode::ContentRegex => Self::ContentRegex(ContentRegexPattern::new(
+                            core,
+                            flags.unwrap_or(""),
+                            content_search_max_file_size,
+                        )?),
                     }
-                )
+                })
             })?;
         Ok(if expr.is_empty() {
             Pattern::None
@@ -128,6 +110,20 @@ impl Pattern {
         }
     }
 
+    pub fn find_string(
+        &self,
+        candidate: &str,
+    ) -> Option<NameMatch> {
+        match self {
+            Self::NameExact(ep) | Self::PathExact(ep) => ep.find(candidate),
+            Self::NameFuzzy(fp) | Self::PathFuzzy(fp) => fp.find(candidate),
+            Self::NameRegex(rp) | Self::PathRegex(rp) => rp.find(candidate),
+            Self::NameTokens(tp) | Self::PathTokens(tp) => tp.find(candidate),
+            Self::Composite(cp) => cp.find_string(candidate),
+            _ => None,
+        }
+    }
+
     /// find the content to show next to the name of the file
     /// when the search involved a content filtering
     pub fn search_content(
@@ -143,6 +139,22 @@ impl Pattern {
         }
     }
 
+    /// find the content to show next to the name of the file
+    /// when the search involved a content filtering and you already
+    /// know the content is there so you don't want to filter by name/path
+    pub fn find_content(
+        &self,
+        candidate: &Path,
+        desired_len: usize, // available space for content match display
+    ) -> Option<ContentMatch> {
+        match self {
+            Self::ContentExact(cp) => cp.get_content_match(candidate, desired_len),
+            Self::ContentRegex(cp) => cp.get_content_match(candidate, desired_len),
+            Self::Composite(cp) => cp.find_content(candidate, desired_len),
+            _ => None,
+        }
+    }
+
     /// get the line of the first match, if any
     pub fn get_match_line_count(
         &self,
@@ -156,7 +168,10 @@ impl Pattern {
         }
     }
 
-    pub fn score_of(&self, candidate: Candidate) -> Option<i32> {
+    pub fn score_of(
+        &self,
+        candidate: Candidate,
+    ) -> Option<i32> {
         match self {
             Self::NameExact(ep) => ep.score_of(candidate.name),
             Self::NameFuzzy(fp) => fp.score_of(candidate.name),
@@ -173,7 +188,10 @@ impl Pattern {
         }
     }
 
-    pub fn score_of_string(&self, candidate: &str) -> Option<i32> {
+    pub fn score_of_string(
+        &self,
+        candidate: &str,
+    ) -> Option<i32> {
         match self {
             Self::NameExact(ep) => ep.score_of(candidate),
             Self::NameFuzzy(fp) => fp.score_of(candidate),
@@ -220,6 +238,4 @@ impl Pattern {
             _ => false,
         }
     }
-
 }
-
