@@ -1,11 +1,11 @@
 use {
     super::{
+        BuildReport,
         bid::{
             BId,
             SortableBId,
         },
         bline::BLine,
-        BuildReport,
     },
     crate::{
         app::AppContext,
@@ -184,7 +184,6 @@ impl<'c> TreeBuilder<'c> {
             name,
             subpath: &subpath.to_string_lossy(),
             path: &path,
-            regular_file: file_type.is_file(),
         };
         let direct_match =
             if let Some(pattern_score) = self.options.pattern.pattern.score_of(candidate) {
@@ -356,7 +355,11 @@ impl<'c> TreeBuilder<'c> {
                     if child.has_match {
                         nb_lines_ok += 1;
                     }
-                    if self.options.max_depth.map_or(false, |max| child.depth > max) {
+                    if self
+                        .options
+                        .max_depth
+                        .map_or(false, |max| child.depth > max)
+                    {
                         break;
                     }
                     if child.can_enter() {
